<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg_BG">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About</source>
        <translation>За програмата</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Лиценз</translation>
    </message>
    <message>
        <source>About Cool Reader</source>
        <translation>За програмата CoolReader</translation>
    </message>
    <message>
        <source>Source Code</source>
        <translation>Изходен код</translation>
    </message>
    <message>
        <source>About CoolReader</source>
        <translation>CoolReader - За програмата</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;CoolReader is free open source e-book viewer based on CoolReader engine.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Source code is available at SourceForge &lt;/span&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; text-decoration: underline;&quot;&gt;http://sourceforge.net/projects/crengine &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;under the terms of GNU GPL2 license.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; text-decoration: underline;&quot;&gt;Third party components used:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Qt %QT_VER% - as GUI library&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;FreeType - font engine&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;HarfBuzz - font kerning&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;ZLib - compressing library&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;libpng - PNG image format support&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;libjpeg - JPEG image format support&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Hyphenation dictionaries - from AlReader&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source code may be downloaded from sourceforge crengine project page:
http://sourceforge.net/projects/crengine/

Latest source code is available from GIT repository:
&gt; git clone git://crengine.git.sourceforge.net/gitroot/crengine/crengine

See README.TXT at root directory of project for build instructions.
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Title</source>
        <translation>Заглавие</translation>
    </message>
    <message>
        <source>Bookmark type</source>
        <translation>Тип отметки</translation>
    </message>
    <message>
        <source>Add bookmark</source>
        <translation>Добавяне на отметка</translation>
    </message>
    <message>
        <source>Position text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Позиция</translation>
    </message>
    <message>
        <source>Correction</source>
        <translation>Корекция</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Коментар</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page 1/10 10%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sample title</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarkListDialog</name>
    <message>
        <source>C</source>
        <translation type="vanished">К</translation>
    </message>
    <message>
        <source>E</source>
        <translation type="vanished">К</translation>
    </message>
    <message>
        <source>P</source>
        <translation type="vanished">П</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="vanished">Тип</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Изход</translation>
    </message>
    <message>
        <source>Remove ALL Bookmarks</source>
        <translation>Премахване на всички отметки</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>Премахване на отметката</translation>
    </message>
    <message>
        <source>Go to Bookmark</source>
        <translation>Преминаване на отметка</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Отметки</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Позиция</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Коментар</translation>
    </message>
    <message>
        <source>Edit Bookmark</source>
        <translation>Редактиране на отметка</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Del</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Esc</source>
        <translation type="unfinished">Esc</translation>
    </message>
    <message>
        <source>Type</source>
        <comment>bookmark type</comment>
        <translation type="unfinished">Тип</translation>
    </message>
    <message>
        <source>P</source>
        <comment>Bookmark type first letter - Position</comment>
        <translation type="unfinished">П</translation>
    </message>
    <message>
        <source>C</source>
        <comment>Bookmark type first letter - Comment</comment>
        <translation type="unfinished">К</translation>
    </message>
    <message>
        <source>E</source>
        <comment>Bookmark type first letter - Correction/Edit</comment>
        <translation type="unfinished">К</translation>
    </message>
</context>
<context>
    <name>CR3View</name>
    <message>
        <source>Error while opening document </source>
        <translation>Възникна грешка при отваряне на документа</translation>
    </message>
    <message>
        <source>Loading: please wait...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportProgressDlg</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export is in progress...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>ISBN</source>
        <translation>ISBN</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Заглавие</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Стойност</translation>
    </message>
    <message>
        <source>Current chapter</source>
        <translation>Глава</translation>
    </message>
    <message>
        <source>Document version</source>
        <translation>Версия на документа</translation>
    </message>
    <message>
        <source>Series number</source>
        <translation>Пореден номер</translation>
    </message>
    <message>
        <source>Current Time</source>
        <translation>Текущо време</translation>
    </message>
    <message>
        <source>Current page</source>
        <translation>Текуща страница</translation>
    </message>
    <message>
        <source>File info</source>
        <translation>Информация за файла</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Име на файл</translation>
    </message>
    <message>
        <source>File path</source>
        <translation>Път до файл</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Размер на файла</translation>
    </message>
    <message>
        <source>Battery state</source>
        <translation>Състояние на батарията</translation>
    </message>
    <message>
        <source>Genres</source>
        <translation>Жанрове</translation>
    </message>
    <message>
        <source>OCR by</source>
        <translation>OCR</translation>
    </message>
    <message>
        <source>Translator</source>
        <translation>Преводач</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Custom info</source>
        <translation>Друга информация</translation>
    </message>
    <message>
        <source>Book info</source>
        <translation>Информация за книгата</translation>
    </message>
    <message>
        <source>File format</source>
        <translation>Файлов формат</translation>
    </message>
    <message>
        <source>Document source URL</source>
        <translation>URL на изходния документ</translation>
    </message>
    <message>
        <source>Publisher city</source>
        <translation>Град</translation>
    </message>
    <message>
        <source>Document properties</source>
        <translation>Свойства на документа</translation>
    </message>
    <message>
        <source>Publication info</source>
        <translation>Информация за публикацията</translation>
    </message>
    <message>
        <source>Publication year</source>
        <translation>Година на издаване</translation>
    </message>
    <message>
        <source>Publication name</source>
        <translation>Име на публикацията</translation>
    </message>
    <message>
        <source>Archive size</source>
        <translation>Размер на архива</translation>
    </message>
    <message>
        <source>Archive name</source>
        <translation>Име на архива</translation>
    </message>
    <message>
        <source>Archive path</source>
        <translation>Път до архива</translation>
    </message>
    <message>
        <source>Publisher</source>
        <translation>Издателство</translation>
    </message>
    <message>
        <source>Property</source>
        <translation>Свойство</translation>
    </message>
    <message>
        <source>Author(s)</source>
        <translation>Автор(и)</translation>
    </message>
    <message>
        <source>Series name</source>
        <translation>Серия</translation>
    </message>
    <message>
        <source>Document author</source>
        <translation>Автор на документа</translation>
    </message>
    <message>
        <source>Total pages</source>
        <translation>Общо страници</translation>
    </message>
    <message>
        <source>Document info</source>
        <translation>Информация за документа</translation>
    </message>
    <message>
        <source>Document date</source>
        <translation>Дата на документа</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Open book file</source>
        <translation>Отваряне на книга</translation>
    </message>
    <message>
        <source>All supported formats (*.fb2 *.txt *.tcr *.rtf *.epub *.html *.htm *.zip);;FB2 books (*.fb2 *.fb2.zip);;Text files (*.txt);;Rich text (*.rtf);;HTML files (*.htm *.html);;EPUB files (*.epub);;ZIP archives (*.zip)</source>
        <translation type="vanished">Всички формати (*.fb2 *.txt *.tcr *.rtf *.epub *.html *.htm *.zip);;Книги FB2 (*.fb2 *.fb2.zip);;Текстови файлове (*.txt);;Текст RTF (*.rtf);;HTML (*.htm *.html);;EPUB (*.epub);;Архиви ZIP (*.zip)</translation>
    </message>
    <message>
        <source>Export document to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WOL book (*.wol)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to WOL format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All supported formats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FB2 books</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rich text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MS Word document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HTML files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>EPUB files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CHM files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOBI files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PalmDOC files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ZIP archives</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindowClass</name>
    <message>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копиране</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощ</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Изглед</translation>
    </message>
    <message>
        <source>Settings...</source>
        <translation>Настройки...</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Изход</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Минимизиране</translation>
    </message>
    <message>
        <source>Bookmark List...</source>
        <translation>Списък с отметки...</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Увеличаване размера на шрифта</translation>
    </message>
    <message>
        <source>Go to first page</source>
        <translation>Към първа страница</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Добавяне на отметка</translation>
    </message>
    <message>
        <source>Add bookmark</source>
        <translation>Добавяне на отметка</translation>
    </message>
    <message>
        <source>Line Up</source>
        <translation>Един ред нагоре</translation>
    </message>
    <message>
        <source>Recent Books</source>
        <translation>Последни книги</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Търсене на текст</translation>
    </message>
    <message>
        <source>Line Down</source>
        <translation>Един ред надолу</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Изнасяне</translation>
    </message>
    <message>
        <source>Previous Chapter</source>
        <translation>Предишна глава</translation>
    </message>
    <message>
        <source>Table of Contents...</source>
        <translation>Съдържание...</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Завъртане</translation>
    </message>
    <message>
        <source>Copy selected text</source>
        <translation>Копиране на избрания текст</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Умаляване размера на шрифта</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Отваряне...</translation>
    </message>
    <message>
        <source>Page Up</source>
        <translation>Предишна страница</translation>
    </message>
    <message>
        <source>Toggle Full Screen</source>
        <translation>Цял екран</translation>
    </message>
    <message>
        <source>Toggle Full Screen mode</source>
        <translation>Цял екран</translation>
    </message>
    <message>
        <source>Go to next page</source>
        <translation>Следваща страница</translation>
    </message>
    <message>
        <source>Increase font size</source>
        <translation>Увеличаване размера на шрифта</translation>
    </message>
    <message>
        <source>Decrease font size</source>
        <translation>Умаляване размера на шрифта</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Относно Qt</translation>
    </message>
    <message>
        <source>File Properties...</source>
        <translation>Свойства...</translation>
    </message>
    <message>
        <source>First Page</source>
        <translation>Първа страница</translation>
    </message>
    <message>
        <source>Last Page</source>
        <translation>Последна страница</translation>
    </message>
    <message>
        <source>Toggle Pages/Scroll</source>
        <translation>Страница/Свитък</translation>
    </message>
    <message>
        <source>Show file properties</source>
        <translation>Свойства</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>Отваряне на файл</translation>
    </message>
    <message>
        <source>Show table of contents</source>
        <translation>Съдържание</translation>
    </message>
    <message>
        <source>Next Chapter</source>
        <translation>Следваща глава</translation>
    </message>
    <message>
        <source>Settings dialog</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Back by page</source>
        <translation>Предишна страница</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Напред</translation>
    </message>
    <message>
        <source>Page Down</source>
        <translation>Следваща страница</translation>
    </message>
    <message>
        <source>About CoolReader</source>
        <translation>За програмата CoolReader</translation>
    </message>
    <message>
        <source>Find text...</source>
        <translation>Търсене на текст...</translation>
    </message>
    <message>
        <source>Show recent books list</source>
        <translation>Показване на списък с последните книги</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>Навигация</translation>
    </message>
    <message>
        <source>Show bookmarks list</source>
        <translation>Показване на списък с отметки</translation>
    </message>
    <message>
        <source>CoolReader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F12</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Forward by one line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back by line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to last page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back in navigation history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to the next position in navigation history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shift+Backspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to next chapter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to previous chapter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>+</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>copy2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy alternative shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Ins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+F1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle Edit Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle edit mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Sentence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move selection to next sentence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>actionPrevSentence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select orevious sentence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Left</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecentBooksDlg</name>
    <message>
        <source>Filename</source>
        <translation>Име на файл</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Заглавие</translation>
    </message>
    <message>
        <source>Recent Books</source>
        <translation>Последни книги</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Автор</translation>
    </message>
    <message>
        <source>Do you really want to remove all history records?</source>
        <translation>Действително ли желаете да премахнете всички записи от списъка с последните отворени книги?</translation>
    </message>
    <message>
        <source>Remove all history items</source>
        <translation>Изтриване списъка с последните отворени книги</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Изтриване на всичко</translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation>Изтриване на записа</translation>
    </message>
    <message>
        <source>Del</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="unfinished">Текст</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search backward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished">Изход</translation>
    </message>
    <message>
        <source>Not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search pattern is not found in document</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDlg</name>
    <message>
        <source>Page</source>
        <translation>Страница</translation>
    </message>
    <message>
        <source>Clock</source>
        <translation>Час</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>Показване на панела с инструменти</translation>
    </message>
    <message>
        <source>Two pages</source>
        <translation>Две страници</translation>
    </message>
    <message>
        <source>Scroll View</source>
        <translation>Свитък</translation>
    </message>
    <message>
        <source>Look &amp; feel</source>
        <translation>Визуален стил</translation>
    </message>
    <message>
        <source>[No hyphenation]</source>
        <translation>[Без сричкопренасяне]</translation>
    </message>
    <message>
        <source>Interline spacing</source>
        <translation>Интервал между редовете</translation>
    </message>
    <message>
        <source>One page</source>
        <translation>Една страница</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Промяна</translation>
    </message>
    <message>
        <source>Show scroll bar</source>
        <translation>Показване на лентата за превъртане</translation>
    </message>
    <message>
        <source>Open recent book</source>
        <translation>Отвори последната книга</translation>
    </message>
    <message>
        <source>Fullscreen display</source>
        <translation>Режим на цял екран</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Не прави нищо</translation>
    </message>
    <message>
        <source>Sample</source>
        <translation>Пример</translation>
    </message>
    <message>
        <source>Styles</source>
        <translation>Стилове</translation>
    </message>
    <message>
        <source>Book name</source>
        <translation>Заглавие</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Прозорец</translation>
    </message>
    <message>
        <source>Window options</source>
        <translation>Прозорец</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Управление</translation>
    </message>
    <message>
        <source>Text color</source>
        <translation>Цвят на текста</translation>
    </message>
    <message>
        <source>.TXT files</source>
        <translation>.TXT файлове</translation>
    </message>
    <message>
        <source>Show menu</source>
        <translation>Показване на менюто</translation>
    </message>
    <message>
        <source>Page margins</source>
        <translation>Бели полета</translation>
    </message>
    <message>
        <source>Show File Open dialog</source>
        <translation>Показване диалог за отваряне на файл</translation>
    </message>
    <message>
        <source>Background color</source>
        <translation>Цвят на фона</translation>
    </message>
    <message>
        <source>Disable automatic formatting</source>
        <translation>Изключване на автоформатирането</translation>
    </message>
    <message>
        <source>The quick brown fox jumps over the lazy dog. </source>
        <translation>Вкъщи не яж сьомга с фиде без ракийка и хапка люта чушчица.</translation>
    </message>
    <message>
        <source>Show list of recent books</source>
        <translation>Показване на списъка с последните книги</translation>
    </message>
    <message>
        <source>Header font</source>
        <translation>Шрифт на колонтитула</translation>
    </message>
    <message>
        <source>Hyphenation</source>
        <translation>Сричкопренасяне</translation>
    </message>
    <message>
        <source>Vew Mode</source>
        <translation>Режим за преглеждане</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Startup action</source>
        <translation>Действие при стартиране</translation>
    </message>
    <message>
        <source>Page header text color</source>
        <translation>Цвят на колонтитула</translation>
    </message>
    <message>
        <source>Show status bar</source>
        <translation>Показване на лентата за състояние</translation>
    </message>
    <message>
        <source>[Algorythmic hyphenation]</source>
        <translation>[Алгоритмично сричкопренасяне]</translation>
    </message>
    <message>
        <source>Page skin</source>
        <translation>Стил на фона</translation>
    </message>
    <message>
        <source>Battery status</source>
        <translation>Състояние на батарията</translation>
    </message>
    <message>
        <source>Text font</source>
        <translation>Шрифт</translation>
    </message>
    <message>
        <source>Show footnotes at bottom of page</source>
        <translation>Показване на бележките под линия в края на страницата</translation>
    </message>
    <message>
        <source>Show page header</source>
        <translation>Показване на колонтитул</translation>
    </message>
    <message>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>11</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>12</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>15</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>20</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>25</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>30</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>40</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>50</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>60</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selection color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Correction color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmark highlight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Solid fill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Inline images zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Integer scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arbitrary scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block images zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block images zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Inline images zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image scaling options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Floating punctuation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable floating punctuation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.35</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.45</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.55</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.65</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.75</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.85</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.95</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.98</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.02</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.05</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.15</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.25</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.35</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.45</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font Gamma</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font hinting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No hinting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use bytecode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autohinting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fallback fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable document internal styles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internal CSS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable document embedded fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>.EPUB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default paragraph style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>First line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Margins:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Before</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>After</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Interline space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text decoration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical align</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stylesheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished">Заглавие</translation>
    </message>
    <message>
        <source>Subtitle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preformatted text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cite / quotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Epigraph</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Poem</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text author</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Footnote link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Footnote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Footnote title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Annotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Justify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No indent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Indent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Big Indent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Outdent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Big Outdent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>20% of line height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>30% of line height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>50% of line height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>100% of line height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>150% of line height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>200% of line height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>400% of line height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5% of line width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10% of line width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>15% of line width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>20% of line width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>30% of line width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bolder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lighter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Increase: 110%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Increase: 120%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Increase: 150%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decrease: 90%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decrease: 80%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decrease: 70%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decrease: 60%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[Default Sans Serif]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[Default Serif]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[Default Monospace]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Silver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lime</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Olive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>White</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maroon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Navy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Purple</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Teal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fuchsia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aqua</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line through</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Baseline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subscript</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Superscript</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment bookmark color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Correction bookmark color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TocDlg</name>
    <message>
        <source>Page</source>
        <translation>Страница</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Заглавие</translation>
    </message>
    <message>
        <source>Table of Contents</source>
        <translation>Съдържание</translation>
    </message>
</context>
<context>
    <name>WolExportDlg</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bits per pixel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Table of Contents levels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
